# Input 1: Parameters
β = 0.95
γ = 2.5
zˣ = 0.0179
ϕ = -0.139
xˣ = 0.0012
r = 1e-8

# Input 2: Define control and states (y,x)                   
(lq,z) = Sym("lq z")
vars = (lq,z)
cntrl = [1]
state = [2]

# Input 3: Model's definition                         
q = exp(lq)
F = [β*exp((1-γ)*z)*(1+q);z]
G = [q;(1-ϕ)*zˣ+ϕ*z]

# Input 4: Deterministic steady state (DSS)  
zss = zˣ
qss = β*exp((1-γ)*zss)/(1-β*exp((1-γ)*zss))
lqss = log(qss)

nsss = (lqss,zss)

# Input 5: Variance-covariance matrix  
S = xˣ

# Build model's solution approximation and compute risky steady state
rss,policy = RiskySS(F,G,vars,nsss,cntrl,state,S)

# Model simulation (plot IRF and policy functions)
T = 20
tau = 5
var_shocked = 2
shock = sqrt(xˣ)
imp = (var_shocked,tau,shock)

variables = ImpResp(T,imp,policy,cntrl,state)

display(plot(1:T,variables[:,1:2],title = "Model_1",label = ["lq" "z"],LineWidth = 3,xlabel="time",ylabel="Responses"))

StateGrid = [-2*sqrt(xˣ) 2*sqrt(xˣ)]
C = PolicyPlot(StateGrid,10,policy)
C = exp.(C .+ rss[1])

include("AnalyticModel_1.jl")
zz = Vector(-2*sqrt(xˣ):4*sqrt(xˣ)/9:2*sqrt(xˣ))
CC1 = zeros(10)
Theta = policy[1]
theta = policy[2]
for i = 1:10
    zx = [zz[i]+zss;0]
    CC1[i] = fanalyticModel_1(zx)
end

c1 = zeros(10,1)
c1[:,1] = C[1,:,:]

zz = zz .+ zss
display(plot(zz,[c1 CC1],title = "Model_1",label = ["Risk Sensitive" "true"],LineWidth = 3,xlabel = "zₜ-zₛₛ",ylabel = "lqₜ-lqₛₛ"))