function [Theta,theta,Omega,omega] = BlanKahn(A,b,cntrl,state,r)
  %BlanKahn solves linear Euler systems with the Blanchard - Kahn (1980) Method.
  %The system has to be express as Y(t+1) = A*Y(t)+b
  %There must be the same number of control variables than explosives roots.
  %Explosives roots are greater or equal than 1+r in absolute value.
  %Author: Gustavo P. Solorzano
  %ADVANCED-ECON.COM  
  
  nc = length(cntrl);
  ns = length(state);
  [n1,n2] = size(A);
  if n1 ~= n2 || n1 ~= nc+ns
    error('Wrong number of variables');
  end  
  [V,Lam] = eig(A);
  btilde = V\b;
  lam = real(diag(Lam));
  conv = abs(lam) < 1+r;
  expl = conv == 0;
  ne = sum(expl);  
  if ne == nc
    %disp('The system satisfies Blanchard - Kahn conditions');
  elseif ne > nc
    error('The system has no solution');
  else
    error('The system has infinite solutions');
  end
  Ze = (eye(ne)-Lam(expl,expl))\btilde(expl);
  Theta = V(cntrl,conv)/V(state,conv);
  theta = (V(cntrl,expl)-V(cntrl,conv)*(V(state,conv)\V(state,expl)))*Ze;
  Omega = A(state,cntrl)*Theta+A(state,state);
  omega = A(state,cntrl)*theta+b(state);
end
